@@ -12,13 +12,13 @@ sub new
 {
 	my ($class, %args) = @_;
 	my $self = bless {}, $class;
-	
+
 	my $filename = $args{'file'} || $args{'filename'} || die "Need filename.";
-	
+
 	$self->{'_FILENAME'}  = $filename;
 	$self->{'_SHEETNAME'} = $args{'sheet'}  || '';
 	$self->{'_STYLES'}    = $args{'styles'} || {};
-		
+
 	return $self;
 }
 
@@ -27,7 +27,7 @@ sub _prepare
 	my $self = shift;
 	my $worksheet = $self->{'_WORKSHEET'};
 	my $workbook  = $self->{'_WORKBOOK'};
-	
+
 	if(!$worksheet)
 	{
 		$self->{'_FH'}->binmode();
@@ -37,7 +37,7 @@ sub _prepare
 		$self->{'_WORKSHEET'} = $worksheet;
 		$self->{'_WORKBOOK_ROW'} = 0;
 	}
-	
+
 	return $self;
 }
 
@@ -52,15 +52,15 @@ sub freeze (@)
 sub close
 {
 	my $self=shift;
-	
+
 	return if $self->{'_CLOSED'};
-	
+
 	$self->{'_WORKBOOK'}->close
 		if $self->{'_WORKBOOK'};
-		
+
 	$self->{'_FH'}->close
 		if $self->{'_FH'};
-		
+
 	$self->{'_CLOSED'} = 1;
 	return $self;
 }
@@ -93,7 +93,7 @@ sub addsheet ($$)
 	$self->{'_SHEETNAME'} = $name;
 	$self->{'_WORKSHEET'} = $worksheet;
 	$self->{'_WORKBOOK_ROW'} = 0;
-	
+
 	return $self;
 }
 
@@ -105,32 +105,37 @@ sub _add_prepared_row
 	my $workbook  = $self->{'_WORKBOOK'};
 	my $row       = $self->{'_WORKBOOK_ROW'};
 	my $col       = 0;
-	
+
+    scalar(@_) < 256 ||
+        die "Excel'97 back-end does not support rows 256 elements or longer";
+
 	for(my $i=0; $i<scalar(@_); $i++)
 	{
 		my %props = %{ $_[$i] };
 		my $value = $props{'content'};
-		
+
 		delete $props{'content'};
 		my $props = \%props;
 
 		my %format;
 		if(%props)
 		{
-			if(my $style = $props->{'style'})
+			if(my $stylelist = $props->{'style'})
 			{
-				my $stprops = $self->{'_STYLES'}->{$style};
-				if(!$stprops)
-				{
-					# warn "Style '$style' is not defined\n";
-				}
-				else
-				{
-					my %a;
-					@a{keys %$stprops} = values %$stprops;
-					@a{keys %$props} = values %$props;
-					$props=\%a;
-				}
+                $stylelist=[$stylelist] unless ref $stylelist;
+
+                foreach my $style (ref $stylelist ? @$stylelist : ($stylelist)) {
+				    my $stprops = $self->{'_STYLES'}->{$style};
+				    if(!$stprops) {
+					    warn "Style '$style' is not defined\n";
+				    }
+				    else {
+					    my %a;
+					    @a{keys %$stprops} = values %$stprops;
+					    @a{keys %$props} = values %$props;
+					    $props=\%a;
+				    }
+                }
 			}
 
 			if ($props->{'font_weight'} eq 'bold')
@@ -153,6 +158,10 @@ sub _add_prepared_row
 			{
 				$format{'color'} = $props->{'font_color'};
 			}
+            if (defined $props->{'bg_color'})
+            {
+                $format{'bg_color'} = $props->{'bg_color'};
+            }
 			if (defined $props->{'font_face'})
 			{
 				$format{'font'}=$props->{'font_face'};
@@ -177,6 +186,10 @@ sub _add_prepared_row
 			{
 				$worksheet->set_column($col,$col,$props->{'width'});
 			}
+            if (defined $props->{'comment'} && length($props->{'comment'}))
+            {
+                $worksheet->write_comment($row,$col,$props->{'comment'});
+            }
 		}
 
 		my @params = ($row, $col++, $value);
@@ -196,11 +209,10 @@ sub _add_prepared_row
 			$worksheet->write(@params);
 		}
 	}
-	
+
 	$self->{'_WORKBOOK_ROW'}++;
-	
+
 	return $self;
 }
 
-
-1;
\ No newline at end of file
+1;
